import { WebElementFinder } from "../../interface/WebElements";
export interface UntilElementCondition {
    visible(): UntilElementCondition;
    forAsLongAs(timeout: number): UntilElementCondition;
    readonly modifierFunc: LogicFunction<boolean>;
    readonly waiter: ElementCondition;
    readonly timeout: number;
    readonly conditionHelpText: string;
}
declare abstract class ElementCondition {
    abstract helpText: string;
    elementText: string;
    abstract isFulfilledFor(element: WebElementFinder): () => Promise<boolean>;
}
export declare class VisibilityCheck extends ElementCondition {
    modifierFunc: (result: boolean) => boolean;
    helpText: string;
    constructor(modifierFunc: (result: boolean) => boolean, helpText?: string);
    isFulfilledFor(element: WebElementFinder): () => Promise<boolean>;
}
export declare class EnabledCheck extends ElementCondition {
    modifierFunc: (result: boolean) => boolean;
    helpText: string;
    constructor(modifierFunc: (result: boolean) => boolean, helpText?: string);
    isFulfilledFor(element: WebElementFinder): () => Promise<boolean>;
}
declare type LogicFunction<T> = (param: T) => T;
export declare class UntilElement implements UntilElementCondition {
    modifierFunc: LogicFunction<boolean>;
    private _timeout;
    waiter: ElementCondition;
    private static readonly id;
    private static readonly negate;
    static readonly is: UntilElement;
    static readonly isNot: UntilElement;
    visible(): UntilElementCondition;
    enabled(): UntilElementCondition;
    private constructor();
    forAsLongAs(timeout: number): UntilElementCondition;
    readonly timeout: number;
    readonly conditionHelpText: string;
    toString(): string;
}
export {};
//# sourceMappingURL=ElementConditions.d.ts.map